# types-s3transfer

[![PyPI - types-s3transfer](https://img.shields.io/pypi/v/types-s3transfer.svg?color=blue)](https://pypi.org/project/types-s3transfer)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-s3transfer.svg?color=blue)](https://pypi.org/project/types-s3transfer)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-s3transfer?color=blue)](https://pypistats.org/packages/types-s3transfer)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations and code completion for [s3transfer](https://pypi.org/project/s3transfer/) package.
This package is a part of [mypy_boto3_builder](https://github.com/youtype/mypy_boto3_builder) project.

## Installation

```bash
python -m pip install types-s3transfer
```

## Usage

Use [mypy](https://github.com/python/mypy) or [pyright](https://github.com/microsoft/pyright) for type checking.

### Latest changes

Builder changelog can be found in [Releases](https://github.com/youtype/mypy_boto3_builder/releases).

## Versioning

`types-s3transfer` version is the same as related `s3transfer` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Support and contributing

Please reports any bugs or request new features in
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/) repository.
